@@ -3,8 +3,7 @@
     Author:        Jan Wielemaker
     E-mail:        J.Wielemaker@vu.nl
     WWW:           http://www.swi-prolog.org
-    Copyright (c)  2018-2020, VU University Amsterdam
-			      CWI, Amsterdam
+    Copyright (c)  2018, VU University Amsterdam
     All rights reserved.
 
     Redistribution and use in source and binary forms, with or without
@@ -36,19 +35,8 @@
 % disable threading. This is needed for PGO (Profile Guided
 % Optimization)
 
-swi :-
-	current_prolog_flag(version_data, swi(_,_,_,_)).
-yap :-
-	current_prolog_flag(version_data, yap(_,_,_,_)).
-sicstus :-
-	current_prolog_flag(version_data, sicstus(_,_,_,_,_)).
-
-have_tabling :-
-	\+ sicstus.
-
-:- if(swi).
-:- use_module(library(statistics), [time/1]).
-:- use_module(library(backcomp), [current_thread/2]).
+:- autoload(library(backcomp), [current_thread/2]).
+:- autoload(library(statistics), [time/1]).
 
 :- set_prolog_flag(gc_thread, false).
 :- (   current_thread(gc, running)
@@ -60,32 +48,21 @@ have_tabling :-
 :- style_check(-singleton).
 
 :- initialization(run(1), main).
-:- endif.
 
 run(F) :-
-	current_output(Out),
-	run(Out, F).
+	run(current_output, F).
 
 run(S, F):-
 	compile_programs,
 	format(S, '~p~t~18| ~t~w~25| ~t~w~32|~n', ['Program', 'Time', 'GC']),
 	format(S, '~`=t~32|~n', []),
 	Total = total(0,0,0),
-	(   program(P, N, F),
-	    run_program(P, N, S, Total),
-	    fail
-	;   true
-	),
+	forall(program(P, N, F),
+	       run_program(P, N, S, Total)),
 	Total = total(Count, Time, GC),
-	(   Count =:= 0
-	->  true
-	;   AvgT is Time/Count,
-	    AvgGC is GC/Count,
-	    format(S, '~t~w~18| ~t~3f~25| ~t~3f~32|~n', [average, AvgT, AvgGC])
-	).
-
-:- multifile user:file_search_path/2.
-:- dynamic   user:file_search_path/2.
+	AvgT is Time/Count,
+	AvgGC is GC/Count,
+	format(S, '~t~w~18| ~t~3f~25| ~t~3f~32|~n', [average, AvgT, AvgGC]).
 
 :- (   file_search_path(bench, _)
    ->  true
@@ -94,20 +71,9 @@ run(S, F):-
    ).
 
 compile_programs :-
-	no_singletons,
-	(   program(P, _),
-	    load_files(P:bench(P), [if(changed)]),
-	    fail
-	;   true
-	).
-
-:- if(sicstus).
-no_singletons :-
-	set_prolog_flag(single_var_warnings, off).
-:- else.
-no_singletons :-
-	style_check(-singleton).
-:- endif.
+	style_check(-singleton),
+	forall(program(P, _),
+	       load_files(P:bench(P), [silent(true), if(changed)])).
 
 run_program(Program, N, S, Total) :-
 	ntimes(Program, N, Time, GC), !,
@@ -116,16 +82,11 @@ run_program(Program, N, S, Total) :-
 	add(3, Total, GC),
 	format(S, '~p~t~18| ~t~3f~25| ~t~3f~32|~n', [Program, Time, GC]).
 
-:- if(sicstus).
-add(_, _, _).
-:- else.
 add(Arg, Term, Time) :-
 	arg(Arg, Term, T0),
 	T is T0+Time,
 	nb_setarg(Arg, Term, T).
-:- endif.
 
-:- if(swi).
 :- if(current_prolog_flag(wine_version, _)).
 get_performance_stats(GC, T):-
 	statistics(gctime, GC),		% SWI-Prolog under Wine
@@ -134,17 +95,10 @@ get_performance_stats(GC, T):-
 get_performance_stats(GC, T):-
 	statistics(gctime, GC),		% SWI-Prolog
 	statistics(cputime, T).
-:- endif.
-:- elif(yap).
-get_performance_stats(GC, T):-
-	statistics(garbage_collection, [_,_,TGC]),
-	statistics(cputime, [TT,_]),
-	GC is TGC / 1000,
-	T is TT / 1000.
 :- else.
 get_performance_stats(GC, T):-
 	statistics(garbage_collection, [_,_,TGC]),
-	statistics(runtime, [TT,_]),
+	statistics(cputime, [TT,_]),
 	GC is TGC / 1000,
 	T is TT / 1000.
 :- endif.
@@ -224,17 +178,6 @@ program(simple_analyzer, 320).
 program(tak,		 35).
 program(zebra,		 166).
 
-% Later additions
-program(sieve,		 16).
-program(queens_clpfd,	 1) :-
-	\+ yap,				% clpfd is broken in YAP 6.5.0
-	\+ sicstus.			% Requires some porting
-program(pingpong,	 8) :-
-	have_tabling.
-program(fib,	         70) :-
-	have_tabling,
-	current_prolog_flag(bounded,false).
-
 
 		 /*******************************
 		 *	    INTERLEAVED		*
