@@ -130,7 +130,6 @@ COMMON(void)		unallocClauseIndexTable(ClauseIndex ci);
 COMMON(void)		deleteActiveClauseFromIndexes(Definition def, Clause cl);
 COMMON(bool)		unify_index_pattern(Procedure proc, term_t value);
 COMMON(void)		deleteIndexes(ClauseList cl, int isnew);
-COMMON(void)		deleteIndexesDefinition(Definition def);
 COMMON(int)		checkClauseIndexSizes(Definition def, int nindexable);
 COMMON(void)		checkClauseIndexes(Definition def);
 COMMON(void)		listIndexGenerations(Definition def, gen_t gen);
@@ -314,9 +313,7 @@ COMMON(word)		pl_import(term_t pred);
 #ifdef O_PROLOG_HOOK
 COMMON(word)		pl_set_prolog_hook(term_t module, term_t old, term_t new);
 #endif
-COMMON(ModuleEnum)	newModuleEnum(int flags);
-COMMON(Module)		advanceModuleEnum(ModuleEnum en);
-COMMON(void)		freeModuleEnum(ModuleEnum en);
+
 
 /* pl-op.c */
 COMMON(int)		currentOperator(Module m, atom_t name, int kind,
@@ -439,6 +436,7 @@ COMMON(int)		get_procedure(term_t descr, Procedure *proc,
 COMMON(int)		checkModifySystemProc(functor_t f);
 COMMON(int)		overruleImportedProcedure(Procedure proc, Module target);
 COMMON(word)		pl_current_predicate(term_t name, term_t functor, control_t h);
+COMMON(foreign_t)	pl_current_predicate1(term_t spec, control_t ctx);
 COMMON(void)		clear_meta_declaration(Definition def);
 COMMON(void)		setMetapredicateMask(Definition def, arg_info *args);
 COMMON(int)		isTransparentMetamask(Definition def, arg_info *args);
@@ -489,7 +487,6 @@ COMMON(int)		startConsult(SourceFile f);
 COMMON(int)		endConsult(SourceFile f);
 COMMON(size_t)		highSourceFileIndex(void);
 COMMON(SourceFile)	lookupSourceFile(atom_t name, int create);
-COMMON(int)		releaseSourceFileNo(int index);
 COMMON(SourceFile)	indexToSourceFile(int index);
 COMMON(void)		cleanupSourceFiles(void);
 COMMON(void)		unlinkSourceFileModule(SourceFile sf, Module m);
@@ -506,18 +503,6 @@ COMMON(int)		exportProcedureSource(SourceFile sf, Module module,
 					      Procedure proc);
 COMMON(void)		registerReloadModule(SourceFile sf, Module module);
 
-#ifdef O_DEBUG
-COMMON(void)		acquireSourceFile_d(SourceFile f,
-					    const char *file, unsigned int line);
-COMMON(int)		releaseSourceFile_d(SourceFile f,
-					    const char *file, unsigned int line);
-#define acquireSourceFile(f) acquireSourceFile_d(f, __FILE__, __LINE__)
-#define releaseSourceFile(f) releaseSourceFile_d(f, __FILE__, __LINE__)
-#else
-COMMON(void)		acquireSourceFile(SourceFile sf);
-COMMON(int)		releaseSourceFile(SourceFile f);
-#endif
-
 /* pl-read.c */
 COMMON(void)		resetRead(void);
 COMMON(int)		f_is_prolog_var_start(wint_t c);
