@@ -89,7 +89,8 @@ typedef struct
 		 *******************************/
 
 struct PL_global_data
-{ pl_defaults_t	defaults;		/* system default settings */
+{ uintptr_t	heap_base;		/* heap-base rounded downwards */
+  pl_defaults_t	defaults;		/* system default settings */
   pl_options_t	options;		/* command-line options */
   State		stateList;		/* list of loaded states */
   int		initialised;		/* Heap is initialised */
@@ -706,7 +707,6 @@ struct PL_local_data
     struct _thread_sig   *sig_tail;	/* Tail of signal queue */
     DefinitionChain local_definitions;	/* P_THREAD_LOCAL predicates */
     simpleMutex scan_lock;		/* Hold for asynchronous scans */
-    alert_channel alert;		/* How to alert the thread */
   } thread;
 #endif
 
