@@ -292,11 +292,7 @@ typedef _sigset_t sigset_t;
 #ifdef ASSERT_H_REQUIRES_STDIO_H
 #include <stdio.h>
 #endif /*ASSERT_H_REQUIRES_STDIO_H*/
-#ifdef NO_ASSERT_H		/* see pl-assert.c */
-#define assert(c) (void)0
-#else
 #include <assert.h>
-#endif
 #include <stdlib.h>
 #include <string.h>
 #include <stddef.h>
@@ -1301,12 +1297,6 @@ typedef struct impl_wrapped
   Code		supervisor;		/* Supervisor to use */
 } impl_wrapped, *ImplWrapped;
 
-typedef struct impl_local
-{ arg_info     *args;			/* Meta and indexing info */
-  LocalDefinitions local;		/* P_THREAD_LOCAL predicates */
-} impl_local, *ImplLocal;
-
-
 typedef struct clause_list
 { arg_info     *args;			/* Meta and indexing info */
   ClauseRef	first_clause;		/* clause list of procedure */
@@ -1477,7 +1467,7 @@ struct definition
     clause_list	clauses;		/* (Indexed) list of clauses */
     impl_foreign foreign;		/* Foreign implementation */
     impl_wrapped wrapped;		/* Wrapped predicate */
-    impl_local   local;			/* P_THREAD_LOCAL predicates */
+    LocalDefinitions local;		/* P_THREAD_LOCAL predicates */
   } impl;
   unsigned int  flags;			/* booleans (P_*) */
   unsigned int  shared;			/* #procedures sharing this def */
@@ -1521,9 +1511,9 @@ typedef struct definition_refs
 #define PROC_IMPORTED	 (0x0004)	/* Procedure is imported */
 
 struct procedure
-{ Definition	definition;		/* definition of procedure */
-  unsigned int  flags;			/* PROC_WEAK */
-  unsigned int	source_no;		/* Source I'm assigned to */
+{ Definition	 definition;		/* definition of procedure */
+  unsigned short flags;			/* PROC_WEAK */
+  unsigned short source_no;		/* Source I'm assigned to */
 };
 
 struct localFrame
@@ -1777,9 +1767,8 @@ struct sourceFile
 #endif
   int		magic;			/* Magic number */
   int		count;			/* number of times loaded */
-  unsigned int	number_of_clauses;	/* number of clauses */
-  unsigned int	index;			/* index number (1,2,...) */
-  unsigned int	references;		/* Reference count */
+  unsigned	number_of_clauses;	/* number of clauses */
+  unsigned	index     : 24;		/* index number (1,2,...) */
   unsigned	system     : 1;		/* system sourcefile: do not reload */
   unsigned	from_state : 1;		/* Loaded from resource DB state */
   unsigned	resource   : 1;		/* Loaded from resource DB file */
@@ -1823,19 +1812,6 @@ struct module
   gen_t		last_modified;	/* Generation I was last modified */
 };
 
-#define MENUM_TEMP	0x1	/* Also enumerate temporary modules */
-
-typedef struct module_enum
-{ TableEnum	tenum;
-  Module        current;
-  int		flags;
-} module_enum, *ModuleEnum;
-
-
-		 /*******************************
-		 *	      TRAIL		*
-		 *******************************/
-
 struct trail_entry
 { Word		address;	/* address of the variable */
 };
