@@ -285,8 +285,6 @@ updateAlerted(PL_local_data_t *ld)
 
   if ( (mask&ALERT_DEBUG) || ld->prolog_flag.occurs_check != OCCURS_CHECK_FALSE )
     ld->slow_unify = TRUE;		/* see VMI B_UNIFY_VAR */
-  else
-    ld->slow_unify = FALSE;
 }
 
 
@@ -1389,18 +1387,20 @@ static Definition
 localDefinition(Definition def ARG_LD)
 { unsigned int tid = LD->thread.info->pl_tid;
   size_t idx = MSB(tid);
-  LocalDefinitions v = def->impl.local.local;
+  LocalDefinitions v = def->impl.local;
 
   if ( !v->blocks[idx] )
-  { size_t bs = (size_t)1<<idx;
-    Definition *newblock;
+  { if ( !v->blocks[idx] )
+    { size_t bs = (size_t)1<<idx;
+      Definition *newblock;
 
-    if ( !(newblock=PL_malloc_uncollectable(bs*sizeof(Definition))) )
-      outOfCore();
+      if ( !(newblock=PL_malloc_uncollectable(bs*sizeof(Definition))) )
+	outOfCore();
 
-    memset(newblock, 0, bs*sizeof(Definition));
-    if ( !COMPARE_AND_SWAP_PTR(&v->blocks[idx], NULL, newblock-bs) )
-      PL_free(newblock);
+      memset(newblock, 0, bs*sizeof(Definition));
+      if ( !COMPARE_AND_SWAP_PTR(&v->blocks[idx], NULL, newblock-bs) )
+	PL_free(newblock);
+    }
   }
 
   if ( !v->blocks[idx][tid] )
@@ -1412,7 +1412,7 @@ localDefinition(Definition def ARG_LD)
 void
 destroyLocalDefinition(Definition def, unsigned int tid)
 { size_t idx = MSB(tid);
-  LocalDefinitions v = def->impl.local.local;
+  LocalDefinitions v = def->impl.local;
   Definition local;
 
   local = v->blocks[idx][tid];
@@ -1426,8 +1426,7 @@ getProcDefinition__LD(Definition def ARG_LD)
 {
 #ifdef O_PLMT
   if ( true(def, P_THREAD_LOCAL) )
-  { MEMORY_ACQUIRE();
-    return localDefinition(def PASS_LD);
+  { return localDefinition(def PASS_LD);
   }
 #endif
 
@@ -1438,7 +1437,7 @@ getProcDefinition__LD(Definition def ARG_LD)
 Definition
 getProcDefinitionForThread(Definition def, unsigned int tid)
 { size_t idx = MSB(tid);
-  LocalDefinitions v = def->impl.local.local;
+  LocalDefinitions v = def->impl.local;
 
   if ( !v->blocks[idx] )
     return NULL;
@@ -2299,9 +2298,7 @@ discardChoicesAfter(LocalFrame fr, enum finished reason ARG_LD)
       for(fr2 = me->frame;
 	  fr2 > delto;
 	  fr2 = fr2->parent)
-      { assert(onStack(local, me));
-	assert(onStack(local, fr2));
-	assert(fr2->clause || true(fr2->predicate, P_FOREIGN));
+      { assert(fr2->clause || true(fr2->predicate, P_FOREIGN));
 
 	if ( true(fr2, FR_WATCHED) )
 	{ char *lSave = (char*)lBase;
@@ -2311,16 +2308,17 @@ discardChoicesAfter(LocalFrame fr, enum finished reason ARG_LD)
 	    Undo(me->mark);
 	    DiscardMark(me->mark);
 	  }
-	  BFR = me;
+	  BFR = me->parent;
 	  frameFinished(fr2, reason PASS_LD);
-	  BFR = BFR->parent;
 	  if ( lSave != (char*)lBase )	/* shifted */
 	  { intptr_t offset = (char*)lBase - lSave;
 
 	    me  = addPointer(me, offset);
+	    me->parent = BFR;		/* not updated because BFR=me->parent */
 	    fr  = addPointer(fr, offset);
 	    fr2 = addPointer(fr2, offset);
 	    delto = addPointer(delto, offset);
+	    fr2->parent = addPointer(fr2->parent, offset);
 	  }
 #if 0					/* What to do if we have multiple */
 	  if ( exception_term )		/* handlers and multiple exceptions? */
@@ -3297,7 +3295,6 @@ next_choice:
 	  { int action;
 
 	    SAVE_REGISTERS(qid);
-	    clearLocalVariablesFrame(FR);
 	    action = tracePort(fr, BFR, REDO_PORT, NULL PASS_LD);
 	    LOAD_REGISTERS(qid);
 	    ch = BFR;			/* can be shifted */
